@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,11 +10,9 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-
-
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings
-from ..operations import statusops, commonops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings
+from ebcli.operations import statusops
 
 
 class StatusController(AbstractBaseController):
@@ -29,4 +27,4 @@ class StatusController(AbstractBaseController):
 
         verbose = self.app.pargs.verbose
 
-        statusops.status(app_name, env_name, verbose)
\ No newline at end of file
+        statusops.status(app_name, env_name, verbose)
