@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,9 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text
-from ..operations import upgradeops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text
+from ebcli.operations import upgradeops
 
 
 class UpgradeController(AbstractBaseController):
@@ -36,4 +36,4 @@ class UpgradeController(AbstractBaseController):
         confirm = self.app.pargs.force
         noroll = self.app.pargs.noroll
 
-        upgradeops.upgrade_env(app_name, env_name, timeout, confirm, noroll)
\ No newline at end of file
+        upgradeops.upgrade_env(app_name, env_name, timeout, confirm, noroll)
