@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -15,12 +15,11 @@ import re
 
 from cement.utils.misc import minimal_logger
 
-from ..lib import elasticbeanstalk, utils
-from ..lib.aws import InvalidParameterValueError
-from ..core import io
-from ..objects.exceptions import TimeoutError
-from ..resources.strings import strings, responses, prompts
-from . import commonops
+from ebcli.lib import elasticbeanstalk, utils
+from ebcli.lib.aws import InvalidParameterValueError
+from ebcli.core import io
+from ebcli.resources.strings import strings, responses, prompts
+from ebcli.operations import commonops
 
 
 LOG = minimal_logger(__name__)
@@ -28,7 +27,6 @@ LOG = minimal_logger(__name__)
 
 def make_cloned_env(clone_request, nohang=False, timeout=None):
     io.log_info('Cloning environment')
-    # get app version from environment
     env = elasticbeanstalk.get_environment(
         app_name=clone_request.app_name,
         env_name=clone_request.original_name
@@ -36,8 +34,12 @@ def make_cloned_env(clone_request, nohang=False, timeout=None):
     clone_request.version_label = env.version_label
     result, request_id = clone_env(clone_request)
 
-    # Print status of env
-    commonops.print_env_details(result, health=False)
+    result.print_env_details(
+        io.echo,
+        elasticbeanstalk.get_environments,
+        elasticbeanstalk.get_environment_resources,
+        health=False
+    )
 
     if nohang:
         return
@@ -58,7 +60,7 @@ def clone_env(clone_request):
                 clone_request.cname = io.prompt_for_cname()
             elif re.match(responses['env.nameexists'], e.message):
                 io.echo(strings['env.exists'])
-                current_environments = commonops.get_env_names(
+                current_environments = elasticbeanstalk.get_environment_names(
                     clone_request.app_name)
                 unique_name = utils.get_unique_name(clone_request.env_name,
                                                     current_environments)
@@ -66,5 +68,3 @@ def clone_env(clone_request):
                     default_name=unique_name)
             else:
                 raise
-
-            # try again
\ No newline at end of file
