@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -14,10 +14,10 @@
 import os
 
 import time
-from ..core import io
-from ..lib import elasticbeanstalk
-from ..resources.strings import prompts
-from . import commonops
+from ebcli.core import io
+from ebcli.lib import elasticbeanstalk
+from ebcli.objects.exceptions import EndOfTestError
+from ebcli.operations import commonops
 
 
 def print_events(app_name, env_name, follow, platform_arn=None):
@@ -43,10 +43,16 @@ def follow_events(app_name, env_name, platform_arn=None):
             )
 
             for event in reversed(events):
-                message = commonops.get_event_string(event)
+                message = commonops.get_event_string(event, long_format=True)
                 streamer.stream_event(message)
                 last_time = event.event_date
 
-            time.sleep(4)
+            _sleep()
+    except EndOfTestError:
+        pass
     finally:
-        streamer.end_stream()
\ No newline at end of file
+        streamer.end_stream()
+
+
+def _sleep():
+    time.sleep(4)
