@@ -692,7 +692,11 @@ prompts = {
                                  'types separated by commas (at least two instance '
                                  'types are recommended).',
     'spot.enable_spot_prompt': 'Would you like to enable Spot Fleet requests '
-                               'for this environment?'
+                               'for this environment?',
+    'sharedlb.shared_load_balancer_request_prompt': 'Your account has one or more sharable load balancers. '
+                                                    'Would you like your new environment to use a shared load balancer?',
+    'sharedlb.shared_load_balancer_prompt': 'Select a shared load balancer',
+    'sharedlb.listener_prompt': 'Select a listener port for your shared load balancer',
 }
 
 alerts = {
@@ -720,6 +724,22 @@ alerts = {
                               "longer supported.",
     'platform.invalidstring': 'Elastic Beanstalk can\'t find a platform '
                               'version that matches "{}".',
+    'sharedlb.listener': 'The selected load balancer has no listeners. '
+                         'This prevents routing requests to your environment instances. '
+                         'Use EC2 to add a listener to your load balancer.',
+    'create.can_not_use_options_together': 'You can\'t use the "{}" and "{}" options together.',
+    'sharedalb.listener': 'The selected load balancer has no listeners. '
+                          'This prevents routing requests to your environment instances. '
+                          'Use EC2 to add a listener to your load balancer.',
+    'sharedlb.missing_shared_lb': 'To specify "--shared-lb-port", also specify "--shared-lb" '
+                                  'and an Application Load Balancer ("--elb-type application").',
+    'sharedlb.wrong_elb_type': 'To specify any shared load balancer options, '
+                                 'also specify an Application Load Balancer ("--elb-type application").',
+    'sharedlb.terminate': 'The environment "{env_name}" uses a shared load balancer. '
+                           'Processes and rules that you added during environment creation '
+                           'will be deleted during environment termination. '
+                           'Resources created outside of Elastic Beanstalk, '
+                           'like load balancers and listeners, will not be affected.',
 }
 
 flag_text = {
@@ -776,7 +796,8 @@ flag_text = {
     'create.on_demand_above_base_percent' : 'percentage of additional On-Demand Instances in a mixed On-Demand / Spot environment',
     'create.min_instances' : 'minimum number of instances in the new environment',
     'create.max_instances' : 'maximum number of instances in the new environment',
-
+    'create.shared_lb': 'ARN of shared load balancer',
+    'create.shared_lb_port': 'Port number for shared load balancer listener',
 
     'deploy.env': 'environment name',
     'deploy.modules': 'modules to deploy',
